.. _modules-node_builder:

##############
 Node builder
##############

.. automodule:: anemoi.graphs.nodes.builder
   :members:
   :exclude-members: BaseNodeBuilder,IcosahedralNodes
   :no-undoc-members:
   :show-inheritance:
